==> GeneSpring_1.0.1.tar.gz: GeneSpring/R/GSload.int.R <==
"GSload.int" <-
function(filename = "GS_R_in.txt") {
#Read the experiment name; It's the first line in the file
expName<-readLines(filename,n=1)

#Read the file the first time
#Unfortunately we have to read the file two times, since it will get confused by the format
# and make all the datapoints factors
#We are skipping the first line, since we know that contains the experiment name
# AND we are reading in a maximum of 200 lines since it is very unlikely there will be more than 200 parameters
expr <- read.table(filename,sep="\t",quote="",skip=1,header=TRUE,row.names=1,blank.lines.skip=FALSE,nrows=200,comment.char="")

#Figure out how many columns there are for each conditions
# GeneSpring names all the columns the same, but R adds a number to it and changes the underscores to dots
#Take the first repeated column name as the number of columns
#...Unless there is only one column
if(length(colnames(expr))>1) numCol <- grep(colnames(expr)[1],colnames(expr)[2:length(colnames(expr))])[1] else numCol <- 1
if(is.na(numCol)) numCol <- dim(expr)[2]

#Now find the empty line which signals the start of the real data.
#The header represents the names of the experimental parameters
n <- charmatch("",row.names(expr))

#Get number of conditions
numConditions <- dim(expr)[2]/numCol

#..and make a table with the experimental parameters
# We only need every numCol'th column, since they are all the same
#We will get a table with the row names representing the experimental parameters
# and the columns contain the values for each of the conditions.
if((numConditions == 1)&&(n > 1)) {
   expparam <- data.frame("1"=as.vector(expr[1:(n-1),1+numCol*0:(numConditions-1)]),row.names=row.names(expr)[1:(n-1)])
} else if(n == 1) {
          expparam <- data.frame(t(1:numConditions),row.names="Parameter")
       } else {
          expparam <- expr[1:(n-1),1+numCol*0:(numConditions-1)]
}

#row.names(expparam)<-paste(row.names(expparam),"()")

#save the column names since we will use them to parse out the columns
cn<-colnames(expr)
#We will read the file again, to read the actual expression values
expr <- read.table(filename,sep="\t",quote="",skip=n+2,header=FALSE,row.names=1,blank.lines.skip=FALSE,comment.char="")

#Get number of genes
ngenes <- dim(expr)[1]

#Create the GSint object by extracting each of the data types as its own matrix
# and make the column names simple numbers (if we have data) and do the same for the expparam object
a.nor <- as.matrix(expr[,grep("N.AVERAGE",cn)])
row.names(a.nor)<-rownames(expr)
if (length(a.nor)!=0) colnames(a.nor)<-1:numConditions

se.nor <- as.matrix(expr[,grep("N.STDERR",cn)])
row.names(se.nor)<-rownames(expr)
if (length(se.nor)!=0) colnames(se.nor)<-1:numConditions

sd.nor <- as.matrix(expr[,grep("N.STDDEV",cn)])
row.names(sd.nor)<-rownames(expr)
if (length(sd.nor)!=0) colnames(sd.nor)<-1:numConditions

n.nor <- as.matrix(expr[,grep("N.N",cn)])
row.names(n.nor)<-rownames(expr)
if (length(n.nor)!=0) colnames(n.nor)<-1:numConditions

a.raw <- as.matrix(expr[,grep("R.AVERAGE",cn)])
row.names(a.raw)<-rownames(expr)
if (length(a.raw)!=0) colnames(a.raw)<-1:numConditions

se.raw <- as.matrix(expr[,grep("R.STDERR",cn)])
row.names(se.raw)<-rownames(expr)
if (length(se.raw)!=0) colnames(se.raw)<-1:numConditions

sd.raw <- as.matrix(expr[,grep("R.STDDEV",cn)])
row.names(sd.raw)<-rownames(expr)
if (length(sd.raw)!=0) colnames(sd.raw)<-1:numConditions

n.raw <- as.matrix(expr[,grep("R.N",cn)])
row.names(n.raw)<-rownames(expr)
if (length(n.raw)!=0) colnames(n.raw)<-1:numConditions

a.ctr <- as.matrix(expr[,grep("C.AVERAGE",cn)])
row.names(a.ctr)<-rownames(expr)
if (length(a.ctr)!=0) colnames(a.ctr)<-1:numConditions

se.ctr <- as.matrix(expr[,grep("C.STDERR",cn)])
row.names(se.ctr)<-rownames(expr)
if (length(se.ctr)!=0) colnames(se.ctr)<-1:numConditions

sd.ctr <- as.matrix(expr[,grep("C.STDDEV",cn)])
row.names(sd.ctr)<-rownames(expr)
if (length(sd.ctr)!=0) colnames(sd.ctr)<-1:numConditions

n.ctr <- as.matrix(expr[,grep("C.N",cn)])
row.names(n.ctr)<-rownames(expr)
if (length(n.ctr)!=0) colnames(n.ctr)<-1:numConditions

colnames(expparam)<-1:numConditions


#return a GSint class object
GSint(expName = expName,
      a.nor = a.nor,
      se.nor = se.nor,
      sd.nor = sd.nor,
      n.nor = n.nor,
      a.raw = a.raw,
      se.raw = se.raw,
      sd.raw = sd.raw,
      n.raw = n.raw,
      a.ctr = a.ctr,
      se.ctr = se.ctr,
      sd.ctr = sd.ctr,
      n.ctr = n.ctr,
      expparam = expparam
)

} #####End of function definition GSload.int()

==> GeneSpring_2.4.0.tar.gz: GeneSpring/R/GSload.int.R <==
"GSload.int" <-
function(filename = "GS_R_in.txt") {
#Read the experiment name; It's the first line in the file
expName<-readLines(filename,n=1)

#Read the file the first time
#Unfortunately we have to read the file two times, since it will get confused by the format
# and make all the datapoints factors
#We are skipping the first line, since we know that contains the experiment name
# AND we are reading in a maximum of 200 lines since it is very unlikely there will be more than 200 parameters
#Changed 16-Feb-2005
#We are no-lomger trying to read the rownames directly, since it failed too often.
# Some formats use # or NA as genenames and this will break the direct conversion of genenames to rownames
expr <- read.table(filename,sep="\t",quote="",skip=1,header=TRUE,row.names=NULL,blank.lines.skip=FALSE,nrows=200,comment.char="",as.is=TRUE)

#Figure out how many columns there are for each conditions
# GeneSpring names all the columns the same, but R adds a number to it and changes the underscores to dots
#Take the first repeated column name as the number of columns
#...Unless there is only one column
if(length(colnames(expr))>2) numCol <- grep(colnames(expr)[2],colnames(expr)[3:length(colnames(expr))])[1] else numCol <- 1

#NOT QUITE SURE WHY THIS IS HERE. CAN WE EVER GET NA FOR numCol
# CHECK IT AND THEN WE PROBABLY NEED TO SUBTRACT ONE
if(is.na(numCol)) numCol <- dim(expr)[2]-1

#Now find the empty line which signals the start of the real data.
#The header represents the names of the experimental parameters
n <- charmatch("",expr[,1])

#Get number of conditions
numConditions <- (dim(expr)[2]-1)/numCol

#..and make a table with the experimental parameters
# We only need every numCol'th column, since they are all the same
#We will get a table with the row names representing the experimental parameters
# and the columns contain the values for each of the conditions.
if(n > 1) {
   expparam <- data.frame(expr[1:(n-1),2+numCol*0:(numConditions-1)],row.names=expr[1:(n-1),1])
} else {
   expparam <- data.frame(t(1:numConditions),row.names="Parameter")
}

#save the column names since we will use them to parse out the columns, if there is more than one column
cn <- colnames(expr[,1:dim(expr)[2]])

#We will read the file again, to read the actual expression values
expr <- read.table(filename,sep="\t",quote="",skip=n+2,header=FALSE,row.names=NULL,blank.lines.skip=FALSE,comment.char="", as.is=TRUE)

#Get number of genes
ngenes <- dim(expr)[1]

#Create the GSint object by extracting each of the data types as its own matrix
# and make the column names simple numbers (if we have data) and do the same for the expparam object
a.nor <- as.matrix(expr[,grep("N.AVERAGE",cn)])
if (length(a.nor)!=0) colnames(a.nor)<-1:numConditions

se.nor <- as.matrix(expr[,grep("N.STDERR",cn)])
if (length(se.nor)!=0) colnames(se.nor)<-1:numConditions

sd.nor <- as.matrix(expr[,grep("N.STDDEV",cn)])
if (length(sd.nor)!=0) colnames(sd.nor)<-1:numConditions

n.nor <- as.matrix(expr[,grep("N.N",cn)])
if (length(n.nor)!=0) colnames(n.nor)<-1:numConditions

a.raw <- as.matrix(expr[,grep("R.AVERAGE",cn)])
if (length(a.raw)!=0) colnames(a.raw)<-1:numConditions

se.raw <- as.matrix(expr[,grep("R.STDERR",cn)])
if (length(se.raw)!=0) colnames(se.raw)<-1:numConditions

sd.raw <- as.matrix(expr[,grep("R.STDDEV",cn)])
if (length(sd.raw)!=0) colnames(sd.raw)<-1:numConditions

n.raw <- as.matrix(expr[,grep("R.N",cn)])
if (length(n.raw)!=0) colnames(n.raw)<-1:numConditions

a.ctr <- as.matrix(expr[,grep("C.AVERAGE",cn)])
if (length(a.ctr)!=0) colnames(a.ctr)<-1:numConditions

se.ctr <- as.matrix(expr[,grep("C.STDERR",cn)])
if (length(se.ctr)!=0) colnames(se.ctr)<-1:numConditions

sd.ctr <- as.matrix(expr[,grep("C.STDDEV",cn)])
if (length(sd.ctr)!=0) colnames(sd.ctr)<-1:numConditions

n.ctr <- as.matrix(expr[,grep("C.N",cn)])
if (length(n.ctr)!=0) colnames(n.ctr)<-1:numConditions

colnames(expparam)<-1:numConditions

#Make the genenames just the list of names from 
genenames <- expr[,1]

#return a GSint class object
GSint(expName = expName,
      a.nor = a.nor,
      se.nor = se.nor,
      sd.nor = sd.nor,
      n.nor = n.nor,
      a.raw = a.raw,
      se.raw = se.raw,
      sd.raw = sd.raw,
      n.raw = n.raw,
      a.ctr = a.ctr,
      se.ctr = se.ctr,
      sd.ctr = sd.ctr,
      n.ctr = n.ctr,
      expparam = expparam,
      genenames = genenames
)

} #####End of function definition GSload.int()
